local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local _

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.Enemy, x.ActiveEnemy, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

a.StatBuffs = {
	1126--[[Mark of the Wild]],
	115921--[[Legacy of the Emperor]],
	20217--[[Blessing of Kings]],
	90363--[[Embrace of the Shale Spider]]
}

a.CritBuffs = {
	116781--[[Legacy of the White Tiger]],
	17007--[[Leader of the Pack]],
	1459--[[Arcane Brilliance]],
	61316--[[Dalaran Brilliance]],
	97229--[[Bellowing Roar]],
	24604--[[Furious Howl]],
	90309--[[Terrifying Roar]],
	126373--[[Fearless Roar]],
	126309--[[Still Water]],
}

a.spells["auto_attack"] = {
	ID = 6603--[[Auto Attack]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	NotIfActive = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["berserking"] = {
	ID = 26297--[[Berserking]],
	Buff = 26297--[[Berserking]],
	BuffUnit = "player",
	NoRangeCheck = true,
	Check = function(z)
		return x.InCombat and x.ActiveEnemy
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["blood_fury"] = {
	ID = 33697--[[Blood Fury]],
	Buff = 33697--[[Blood Fury]],
	BuffUnit = "player",
	NoRangeCheck = true,
	Check = function(z)
		return x.InCombat and x.ActiveEnemy
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["synapse_springs"] = {
	Type = "item",
	NoRangeCheck = true,
	Check = function(z)
		local gloves = GetInventoryItemID("player", 10)
		z.ID = gloves
		z.FlashID = gloves
		return x.InCombat and x.ActiveEnemy and s.ItemCooldown(gloves) <= x.GCD
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["virmens_bite_potion,if=buff.bloodlust.react|target.time_to_die<=60"] = {
	Type = "item",
	ID = 76089--[[Virmen's Bite]],
	Buff = 105697--[[Virmen's Bite]],
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.ActiveEnemy and s.Boss("target")
	end,
	CheckLast = function(z)
		return x.Bloodlust or (x.TimeToDie <= 60)
	end,
	FlashID = 76089--[[Virmen's Bite]],
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["purifying_brew,if=stagger.amount&stagger.amount%health.max*100>20-buff.shuffle.remains"] = {
	ID = 119582--[[Purifying Brew]],
	NoGCD = true,
	FlashColor = "Yellow",
--	ConsumeDebuff = 124274--[[Moderate Stagger]],
--	ConsumeBuffUnit = "player", 
	Check = function(z)
		return x.StaggerAmount > 0 and (x.StaggerAmount  * 100 / x.MaxHealth) > 20 - x.ShuffleRemains
	end,
}

a.spells["Purify Heavy Stagger"] = {
	ID = 119582--[[Purifying Brew]],
	NoGCD = true,
	FlashColor = "Red",
	FlashBlink = true,
	ConsumeDebuff = 124273--[[Heavy Stagger]],
	ConsumeBuffUnit = "player", 
}

a.spells["Purify Moderate Stagger"] = {
	ID = 119582--[[Purifying Brew]],
	NoGCD = true,
	FlashColor = "Yellow",
	ConsumeDebuff = 124274--[[Moderate Stagger]],
	ConsumeBuffUnit = "player", 
	Check = function(z)
		return x.Chi > 2 or x.ShuffleRemains > 6
	end,
}

a.spells["Healing Elixiers"] = {
	ID = 119582--[[Purifying Brew]],
	NoGCD = true,
	FlashColor = "Yellow",
	ConsumeBuff = 134563--[[Healing Elixiers]],
	ConsumeBuffUnit = "player", 
	Check = function(z)
		return s.HealthPercent("player") < 85
	end,
}

a.spells["Blackout Kick (Brewmaster)"] = {
	ID = 100784--[[Blackout Kick]],
	Buff = 115307--[[Shuffle]],
	BuffUnit = "player",
	EnemyTargetNeeded = true,
	Check = function(z)
		if s.Boss("target") then
			z.EarlyRefresh = 6
		else
			z.EarlyRefresh = 3
		end
		return x.NoCC
	end,
}

a.spells["blackout_kick,if=buff.shuffle.remains<=1.5"] = {
	ID = 100784--[[Blackout Kick]],
	Buff = 115307--[[Shuffle]],
	BuffUnit = "player",
	EarlyRefresh = 1.5,
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC
	end,
}

a.spells["blackout_kick,if=chi=chi.max&energy.time_to_max<=2"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC and x.Chi == x.MaxChi and x.TimeToMax <= 2
	end,
}

a.spells["blackout_kick,if=chi>=chi.max-1&cooldown.keg_smash.remains<=1"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC and x.Chi >= x.MaxChi - 1 and x.KegSmashCDRemains <= 1 + x.GCD
	end,
}

a.spells["blackout_kick,if=chi=chi.max"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC and x.Chi == x.MaxChi
	end,
}

a.spells["Nimble Brew"] = {
	ID = 137562--[[Nimble Brew]],
	NoRangeCheck = true,
	NoGCD = true,
	FlashBlink = true,
	Check = function(z)
		local eventIndex = C_LossOfControl.GetNumEvents()
		while (eventIndex > 0) do
			local locType, _, _, _, _, timeRemaining = C_LossOfControl.GetEventInfo(eventIndex)
			if (locType == "ROOT" or locType == "STUN_MECHANIC" or locType == "FEAR") and timeRemaining then
				return timeRemaining > 1.5
			end
			eventIndex = eventIndex - 1
		end
	end,
}

a.spells["Tiger's Lust"] = {
	ID = 116841--[[Tiger's Lust]],
	NoRangeCheck = true,
	FlashBlink = true,
	FlashColor = "Aqua",
	Check = function(z)
		local _, runSpeed = GetUnitSpeed("player")
		return s.HasTalent(116841--[[Tiger's Lust]]) and (runSpeed / 7 * 100 < 100 or s.Buff(134370--[[Down Draft]], "target") or s.Buff(123461--[[Get Away!]], "target"))
	end,
}

a.spells["chi_wave,if=talent.chi_wave.enabled&energy.time_to_max>2"] = {
	ID = 115098--[[Chi Wave]],
	Check = function(z)
		return s.HasTalent(115098--[[Chi Wave]]) and x.TimeToMax > (x.GCD + 2)
	end,
}

a.spells["chi_wave,if=talent.chi_wave.enabled"] = {
	ID = 115098--[[Chi Wave]],
	Check = function(z)
		return s.HasTalent(115098--[[Chi Wave]])
	end,
}

a.spells["zen_sphere,cycle_targets=1,if=talent.zen_sphere.enabled&energy.time_to_max>2&!dot.zen_sphere.ticking"] = {
	ID = 124081--[[Zen Sphere]],
	Buff = 124081--[[Zen Sphere]],
	BuffUnit = "player",
	NoRangeCheck = true,
	Unit = "player",
	Check = function(z)
		return x.ShouldTemporaryBuff and s.HasTalent(124081--[[Zen Sphere]]) and x.TimeToMax > (x.GCD + 2)
	end,
}

a.spells["zen_sphere,cycle_targets=1,if=talent.zen_sphere.enabled&!dot.zen_sphere.ticking"] = {
	ID = 124081--[[Zen Sphere]],
	Buff = 124081--[[Zen Sphere]],
	BuffUnit = "player",
	NoRangeCheck = true,
	Unit = "player",
	Check = function(z)
		return x.ShouldTemporaryBuff and s.HasTalent(124081--[[Zen Sphere]])
	end,
}

a.spells["chi_burst,if=talent.chi_burst.enabled&energy.time_to_max>2"] = {
	ID = 123986--[[Chi Burst]],
	Check = function(z)
		return s.HasTalent(123986--[[Chi Burst]]) and x.TimeToMax > (x.GCD + 2)
	end,
	NotWhileMoving = true,
}

a.spells["chi_burst,if=talent.chi_burst.enabled"] = {
	ID = 123986--[[Chi Burst]],
	Check = function(z)
		return s.HasTalent(123986--[[Chi Burst]])
	end,
	NotWhileMoving = true,
}

a.spells["chi_brew,if=talent.chi_brew.enabled&chi=0"] = {
	ID = 115399--[[Chi Brew]],
	NoRangeCheck = true,
	Check = function(z)
		return s.HasTalent(115399--[[Chi Brew]]) and x.Chi == 0
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["chi_brew,if=talent.chi_brew.enabled&chi<=2&(trinket.proc.agility.react|(charges=1&recharge_time<=10)|charges=2|target.time_to_die<charges*10)"] = {
	ID = 115399--[[Chi Brew]],
	NoRangeCheck = true,
	Check = function(z)
		local charges, maxCharges, timeLastCast, cooldownDuration = GetSpellCharges(115399--[[Chi Brew]])
		local recharge_time
		if charges < maxCharges then
			recharge_time = cooldownDuration - GetTime() + timeLastCast
		else
			recharge_time = 0
		end
		return x.ShouldTemporaryBuff and x.InCombat and s.HasTalent(115399--[[Chi Brew]]) and x.Chi <= 2 and (x.TrinketProcAgilityRemains > x.Lag or (charges == 1 and recharge_time <= 10) or charges == 2 or x.TimeToDie < charges * 10)
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["chi_brew,if=talent.chi_brew.enabled&chi<=2&((charges=1&recharge_time<=10)|charges=2|target.time_to_die<charges*10)"] = {
	ID = 115399--[[Chi Brew]],
	NoRangeCheck = true,
	Check = function(z)
		local charges, maxCharges, timeLastCast, cooldownDuration = GetSpellCharges(115399--[[Chi Brew]])
		local recharge_time
		if charges < maxCharges then
			recharge_time = cooldownDuration - GetTime() + timeLastCast
		else
			recharge_time = 0
		end
		return x.ShouldTemporaryBuff and x.InCombat and s.HasTalent(115399--[[Chi Brew]]) and x.Chi <= 2 and ((charges == 1 and recharge_time <= 10) or charges == 2 or x.TimeToDie < charges * 10)
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["Charging Ox Wave"] = {
	ID = 119392--[[Charging Ox Wave]],
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	Check = function(z)
		return s.HasTalent(119392--[[Charging Ox Wave]]) and not s.MeleeDistance("target")
	end,
	FlashColor = "Pink",
}

a.spells["Dampen Harm"] = {
	ID = 122278--[[Dampen Harm]],
	Check = function(z)
		return s.HasTalent(122278--[[Dampen Harm]]) and s.HealthPercent("player") < 50 and x.ShouldTemporaryBuff and x.InCombat
	end,
	FlashColor = "Red",
	NoGCD = true,
}

a.spells["Diffuse Magic"] = {
	ID = 122783--[[Diffuse Magic]],
	Check = function(z)
		return s.HasTalent(122783--[[Diffuse Magic]]) and s.Debuff(nil, "player", nil, false, true, false, "Magic")
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["Detox"] = {
	ID = 115450--[[Detox]],
	Check = function(z)
		return s.Debuff(nil, "player", nil, false, true, false, "Poison|Disease")
	end,
	FlashColor = "White",
}

a.spells["invoke_xuen,if=talent.invoke_xuen.enabled"] = {
	ID = 123904--[[Invoke Xuen, the White Tiger]],
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC and s.HasTalent(123904--[[Invoke Xuen, the White Tiger]]) and x.InCombat
	end,
	Continue = true,
	FlashColor = "Purple",
}

a.spells["breath_of_fire"] = {
	ID = 115181--[[Breath of Fire]],
	MyDebuff = 115181--[[Breath of Fire]],
	RequireDebuff = 115180--[[Dizzying Haze]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC
	end,
}

a.spells["rising_sun_kick,if=debuff.rising_sun_kick.down"] = {
	ID = 107428--[[Rising Sun Kick]],
	MyDebuff = 130320--[[Rising Sun Kick]],
	UseBuffID = true,
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC
	end,
}

a.spells["rising_sun_kick"] = {
	ID = 107428--[[Rising Sun Kick]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC
	end,
}

a.spells["rising_sun_kick,if=chi=chi.max"] = {
	ID = 107428--[[Rising Sun Kick]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.Chi == x.MaxChi
	end,
}

a.spells["fists_of_fury,if=buff.energizing_brew.down&energy.time_to_max>4&buff.tiger_power.remains>4"] = {
	ID = 113656--[[Fists of Fury]],
	RequireBuff = 125359--[[Tiger Power]],
	RequireBuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	NoRangeCheck = true,
	NotWhileMoving = true,
	Check = function(z)
		local FoFDuration = (4 / (1 + (UnitSpellHaste("player") / 100)))
		z.RequireMoreBuffTime = FoFDuration
		return x.NoCC and s.BuffDuration(115288--[[Energizing Brew]], "player") <= x.GCD and x.TimeToMax > (x.GCD + FoFDuration)
	end,
}

a.spells["energizing_brew,if=energy.time_to_max>5"] = {
	ID = 115288--[[Energizing Brew]],
	Buff = 115288--[[Energizing Brew]],
	BuffUnit = "player",
	Check = function(z)
		return x.ShouldTemporaryBuff and x.InCombat and x.TimeToMax > (x.GCD + 5)
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["Rushing Jade Wind (Brewmaster)"] = {
	ID = 116847--[[Rushing Jade Wind]],
	Buff = 116847--[[Rushing Jade Wind]],
	NoRangeCheck = true,
	Check = function(z)
		return x.ActiveEnemies >= 3 and s.HasTalent(116847--[[Rushing Jade Wind]]) and x.Energy + x.KegSmashCDRemains * x.EnergyPerSecond >= 80
	end,
}

a.spells["Rushing Jade Wind (WW)"] = {
	ID = 116847--[[Rushing Jade Wind]],
	Buff = 116847--[[Rushing Jade Wind]],
	NoRangeCheck = true,
	Check = function(z)
		return x.NoCC and x.ActiveEnemies >= 3 and s.HasTalent(116847--[[Rushing Jade Wind]])
	end,
}

a.spells["rushing_jade_wind,if=talent.rushing_jade_wind.enabled"] = {
	ID = 116847--[[Rushing Jade Wind]],
	Buff = 116847--[[Rushing Jade Wind]],
	NoRangeCheck = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.ShouldTemporaryBuff and s.HasTalent(116847--[[Rushing Jade Wind]])
	end,
}

a.spells["Spinning Crane Kick (Brewmaster)"] = {
	ID = 101546--[[Spinning Crane Kick]],
	Check = function(z)
		return x.ActiveEnemies >= 3 and not s.HasTalent(116847--[[Rushing Jade Wind]]) and x.Energy + x.KegSmashCDRemains * x.EnergyPerSecond >= 80
	end,
}

a.spells["spinning_crane_kick,if=!talent.rushing_jade_wind.enabled&energy.time_to_max<=1"] = {
	ID = 101546--[[Spinning Crane Kick]],
	Check = function(z)
		return not s.HasTalent(116847--[[Rushing Jade Wind]]) and x.TimeToMax <= 1
	end,
}

a.spells["spinning_crane_kick,if=!talent.rushing_jade_wind.enabled&energy+energy.regen*cooldown.keg_smash.remains>=80"] = {
	ID = 101546--[[Spinning Crane Kick]],
	Check = function(z)
		return not s.HasTalent(116847--[[Rushing Jade Wind]]) and x.Energy + x.KegSmashCDRemains * x.EnergyPerSecond >= 80
	end,
}

a.spells["spinning_crane_kick"] = {
	ID = 101546--[[Spinning Crane Kick]],
	Check = function(z)
		return x.NoCC and not s.HasTalent(116847--[[Rushing Jade Wind]])
	end,
}

a.spells["keg_smash"] = {
	ID = 121253--[[Keg Smash]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC
	end,
}

a.spells["expel_harm,if=incoming_damage_2>health.max*0.3"] = {
	ID = 115072--[[Expel Harm]],
	EnemyTargetNeeded = false,
	Check = function(z)
		return s.HealthPercent("player") < 80 and x.IncomingDamage2 > x.MaxHealth * 0.3
	end,
}

a.spells["Expel Harm (Windwalker)"] = {
	ID = 115072--[[Expel Harm]],
	EnemyTargetNeeded = false,
	Check = function(z)
		return s.HealthPercent("player") < 80 and x.Chi <= (x.MaxChi - 2) 
	end,
	Continue = true,
}

a.spells["Flying Serpent Kick"] = {
	ID = 101545--[[Flying Serpent Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return not s.MeleeDistance("target")
	end,
	FlashColor = "Pink",
}

a.spells["jab,if=energy.time_to_max<=1"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.TimeToMax <= 1
	end,
	FlashID = {100780, 115698, 108967, 130257, 108557, 115687, 115693, 115695, 125661},
}

a.spells["jab,if=energy+energy.regen*cooldown.keg_smash.remains>=80"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.Energy + x.KegSmashCDRemains * x.EnergyPerSecond >= 80
	end,
	FlashID = {100780, 115698, 108967, 130257, 108557, 115687, 115693, 115695, 125661},
}

a.spells["jab,if=chi.max-chi>=2"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and (x.MaxChi - x.Chi) >= 2 and x.Energy >= 40
	end,
	FlashID = {100780, 115698, 108967, 130257, 108557, 115687, 115693, 115695, 125661},
}

a.spells["jab,if=talent.rushing_jade_wind.enabled&energy.time_to_max<cooldown.rushing_jade_wind.remains&energy.time_to_max<cooldown.keg_smash.remains"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and s.HasTalent(116847--[[Rushing Jade Wind]]) and x.TimeToMax < s.SpellCooldown(116847--[[Rushing Jade Wind]]) and x.TimeToMax < x.KegSmashCDRemains
	end,
	FlashID = {100780, 115698, 108967, 130257, 108557, 115687, 115693, 115695, 125661},
}

a.spells["jab,if=buff.lucidity.up"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.BuffLucidityRemains > x.GCD
	end,
	FlashID = {100780, 115698, 108967, 130257, 108557, 115687, 115693, 115695, 125661},
}

a.spells["jade_serpent_statue"] = {
	ID = 115313--[[Jade Serpent Statue]],
	NoRangeCheck = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and GetTotemInfo(1) == false
	end,
}

a.spells["black_ox_statue"] = {
	ID = 115315--[[Black Ox Statue]],
	NoRangeCheck = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and GetTotemInfo(1) == false
	end,
}

a.spells["crackling_jade_lightning,if=buff.bloodlust.up&buff.lucidity.up"] = {
	ID = 117952--[[Crackling Jade Lightning]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.Bloodlust and x.BuffLucidityRemains > x.GCD
	end,
}

a.spells["guard,if=buff.shuffle.remains>6&incoming_damage_2>health.max*0.5"] = {
	ID = 115295--[[Guard]],
	Buff = 115295--[[Guard]],
	BuffUnit = "player",
	ConsumeBuff = 118636--[[Power Guard]],
	ConsumeBuffUnit = "player", 
	NoGCD = true,
	FlashColor = "Yellow",
	Check = function(z)
		return x.ShuffleRemains > 6 and s.SpellCooldown(115295--[[Guard]]) <= x.GCD and s.SpellCooldown(123402--[[Glyph of Guard]]) <= x.GCD and x.IncomingDamage2 > x.MaxHealth * 0.5
	end,
	FlashID = {115295--[[Guard]], 123402--[[Glyph of Guard]]},
}

a.spells["Guard"] = {
	ID = 115295--[[Guard]],
	Buff = 115295--[[Guard]],
	BuffUnit = "player",
	ConsumeBuff = 118636--[[Power Guard]],
	ConsumeBuffUnit = "player", 
	NoGCD = true,
	FlashColor = "Yellow",
	Check = function(z)
		return x.Chi >= 3 and s.SpellCooldown(115295--[[Guard]]) <= x.GCD and s.SpellCooldown(123402--[[Glyph of Guard]]) <= x.GCD
	end,
}

a.spells["tiger_palm,if=buff.tiger_power.down"] = {
	ID = 100787--[[Tiger Palm]],
	Buff = 125359--[[Tiger Power]],
	BuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC
	end,
}

a.spells["tiger_palm"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC
	end,
}

a.spells["tiger_palm,if=buff.combo_breaker_tp.react&(buff.combo_breaker_tp.remains<=2|energy.time_to_max>=2)"] = {
	ID = 100787--[[Tiger Palm]],
	ConsumeBuff =  118864--[[Combo Breaker: Tiger Palm]],
	ConsumeBuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	NoPowerCheck = true,
	EvenIfNotUsable = true,
	Check = function(z)
		return x.NoCC and (s.BuffDuration(118864--[[Combo Breaker: Tiger Palm]], "player") <= x.GCD + 2 or x.TimeToMax >= x.GCD + 2)
	end,
}

a.spells["tiger_palm,if=chi>=2&buff.tiger_power.remains<=4"] = {
	ID = 100787--[[Tiger Palm]],
	Buff = 125359--[[Tiger Power]],
	BuffUnit = "player",
	EarlyRefresh = 4,
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.Chi >= 2
	end,
}

a.spells["tiger_palm,if=buff.muscle_memory.up&buff.lucidity.up"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.BuffMuscleMemoryRemains > x.GCD and x.BuffLucidityRemains > x.GCD
	end,
}

a.spells["tiger_palm,if=buff.muscle_memory.up&!buff.tiger_power.up"] = {
	ID = 100787--[[Tiger Palm]],
	Buff = 125359--[[Tiger Power]],
	BuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.BuffMuscleMemoryRemains > x.GCD
	end,
}

a.spells["tiger_palm,if=buff.muscle_memory.up"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.BuffMuscleMemoryRemains > x.GCD
	end,
}

a.spells["blackout_kick,if=buff.combo_breaker_bok.react"] = {
	ID = 100784--[[Blackout Kick]],
	ConsumeBuff =  116768--[[Combo Breaker: Blackout Kick]],
	ConsumeBuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	NoPowerCheck = true,
	EvenIfNotUsable = true,
	Check = function(z)
		return x.NoCC
	end,
}

a.spells["blackout_kick,if=energy+energy.regen*cooldown.rising_sun_kick.remains>=40"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.Energy + x.EnergyPerSecond * (s.SpellCooldown(107428--[[Rising Sun Kick]]) + x.GCD) >= 40
	end,
}

a.spells["blackout_kick,if=buff.muscle_memory.up&chi>1&!buff.serpents_zeal.up"] = {
	ID = 100784--[[Blackout Kick]],
	Buff = 127722--[[Serpent's Zeal]],
	BuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.BuffMuscleMemoryRemains > x.GCD and x.Chi > 1
	end,
}

a.spells["renewing_mist"] = {
	ID = 115151--[[Renewing Mist]],
	NoRangeCheck = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.InGroup() and s.InGroup() > 1
	end,
}

a.spells["uplift"] = {
	ID = 116670--[[Uplift]],
	NoRangeCheck = true,
	Check = function(z)
		if not s.InGroup() then
			return false
		end
		local group
		if s.InRaid() then
			group = "raid"
		else
			group = "party"
		end
		local mistCount = 0
		local healCount = 0
		for i= 1, GetNumGroupMembers() do
			if s.MyBuffDuration(s.SpellName(115151--[[Renewing Mist]]), group..i) > x.GCD then
				mistCount = mistCount + 1
				if s.HealthPercent(group..i) < 85 then
					healCount = healCount + 1
				elseif s.HealthPercent(group..i) < 20 then
					healCount = healCount + 3
				end
			end
		end
		if healCount >= 3 or (not s.MeleeDistance("target") and mistCount > 0 and x.Chi >= 4) then
			return x.ShouldTemporaryBuff and x.InCombat
		else
			return false
		end
	end,
}

a.spells["tigereye_brew,if=buff.tigereye_brew_use.down&buff.tigereye_brew.stack=20"] = {
	ID = 116740--[[Tigereye Brew]],
	Buff = 116740--[[Tigereye Brew]],
	BuffUnit = "player",
	UseBuffID = true,
	ConsumeBuff = 125195--[[Tigereye Brew]],
	ConsumeUseBuffID = true,
	ConsumeBuffUnit = "player",
	ConsumeStack = 20,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return x.ShouldTemporaryBuff
	end,
}

a.spells["tigereye_brew,if=buff.tigereye_brew_use.down&trinket.proc.agility.react"] = {
	ID = 116740--[[Tigereye Brew]],
	Buff = 116740--[[Tigereye Brew]],
	BuffUnit = "player",
	UseBuffID = true,
	ConsumeBuff = 125195--[[Tigereye Brew]],
	ConsumeUseBuffID = true,
	ConsumeBuffUnit = "player",
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.TrinketProcAgilityRemains > x.Lag
	end,
}

a.spells["tigereye_brew,if=buff.tigereye_brew_use.down&chi>=2&(trinket.proc.agility.react|buff.tigereye_brew.stack>=15|target.time_to_die<40)&debuff.rising_sun_kick.up&buff.tiger_power.up"] = {
	ID = 116740--[[Tigereye Brew]],
	Buff = 116740--[[Tigereye Brew]],
	BuffUnit = "player",
	UseBuffID = true,
	ConsumeBuff = 125195--[[Tigereye Brew]],
	ConsumeUseBuffID = true,
	ConsumeBuffUnit = "player",
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.Chi >= 2 and (s.BuffStack(125195--[[Tigereye Brew]], "player") >= 15 or (x.TimeToDie < 40 and not s.Dummy("target"))) and x.DebuffRisingSunKickRemains > x.Lag and s.BuffDuration(125359--[[Tiger Power]], "player") > x.Lag
	end,
}

a.spells["mana_tea,if=buff.mana_tea.react>=2&mana.pct<=25"] = {
	ID = 115294--[[Mana Tea]],
	ConsumeBuff = 115867--[[Mana Tea]],
	ConsumeUseBuffID = true,
	ConsumeBuffUnit = "player",
	ConsumeStack = 2,
	Continue = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.PowerPercent("player", SPELL_POWER_MANA) <= 25
	end,
}

a.spells["tiger_palm,if=buff.tiger_power.remains<=3"] = {
	ID = 100787--[[Tiger Palm]],
	Buff = 125359--[[Tiger Power]],
	BuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	EarlyRefresh = 3,
	Check = function(z)
		return x.NoCC and x.Chi >= 2 and s.Buff(125359--[[Tiger Power]], "player")
	end,
}

a.spells["tiger_palm,if=buff.tiger_power.down&target.debuff.rising_sun_kick.remains>1&energy.time_to_max>1"] = {
	ID = 100787--[[Tiger Palm]],
	Buff = 125359--[[Tiger Power]],
	BuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and (x.Chi >= 2 or s.BuffDuration(118864--[[Combo Breaker: Tiger Palm]], "player") > x.GCD) and x.DebuffRisingSunKickRemains > (x.GCD + 1) and x.TimeToMax > (x.GCD + 1)
	end,
}

a.spells["elusive_brew"] = {
	ID = 115308--[[Elusive Brew]],
	Buff = 115308--[[Elusive Brew]],
	BuffUnit = "player",
	UseBuffID = true,
	ConsumeBuff = 128939--[[Elusive Brew]],
	ConsumeBuffUnit = "player",
	ConsumeUseBuffID = true,
	ConsumeStack = 9,
	Check = function(z)
		z.FlashBlink = false
		if x.ThreatPercent < 100 then
			z.FlashColor = "Pink"
		else
			z.FlashColor = "Yellow"
			if s.BuffStack(128939--[[Elusive Brew]], "player") == 15 then
				z.FlashBlink = true
			end
		end
		return x.InCombat
	end,
	NoGCD = true,
	Continue = true,
}

a.spells["fortifying_brew,if=incoming_damage_2>health.max*0.5"] = {
	ID = 115203--[[Fortifying Brew]],
	Buff = 120954--[[Fortifying Brew]],
	BuffUnit = "player",
	FlashColor = "Red",
	Check = function(z)
		return x.ShouldTemporaryBuff and x.InCombat and x.IncomingDamage2 > x.MaxHealth * 0.5
	end,
	NoGCD = true,
}

a.spells["stance,choose=sturdy_ox"] = {
	Type = "form",
	ID = 115069--[[Stance of the Sturdy Ox]],
	Buff = 115069--[[Stance of the Sturdy Ox]],
	BuffUnit = "player",
	FlashColor = "Green",
	Check = function(z)
		return x.ShouldPermanentBuff
	end,
}

a.spells["stance,choose=fierce_tiger"] = {
	Type = "form",
	ID = 103985--[[Stance of the Fierce Tiger]],
	Buff = 103985--[[Stance of the Fierce Tiger]],
	BuffUnit = "player",
	FlashColor = "Green",
	Check = function(z)
		return x.ShouldPermanentBuff
	end,
}

a.spells["stance,choose=wise_serpent"] = {
	Type = "form",
	ID = 115070--[[Stance of the Wise Serpent]],
	Buff = 115070--[[Stance of the Wise Serpent]],
	BuffUnit = "player",
	FlashColor = "Green",
	Check = function(z)
		return x.ShouldPermanentBuff
	end,
}

a.spells["Legacy of the Emperor"] = {
	ID = 115921--[[Legacy of the Emperor]],
	Buff = a.StatBuffs,
	EarlyRefresh = 10,
	NoRangeCheck = true,
	BuffUnit = "raid",
	FlashColor = "Green",
	Check = function(z)
		return x.ShouldTemporaryBuff
	end,
}

a.spells["Legacy of the White Tiger"] = {
	ID = 116781--[[Legacy of the White Tiger]],
	Buff = a.CritBuffs,
	EarlyRefresh = 10,
	NoRangeCheck = true,
	BuffUnit = "raid",
	FlashColor = "Green",
	Check = function(z)
		return x.ShouldTemporaryBuff
	end,
}

a.spells["Spear Hand Strike"] = {
	ID = 116705--[[Spear Hand Strike]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	NoGCD = true,
	FlashColor = "Aqua",
}

a.spells["Paralysis"] = {
	ID = 115078--[[Paralysis]],
	EnemyTargetNeeded = true,
	Interrupt = 1,
	Check = function(z)
		return not s.Boss("target")
	end,
	FlashColor = "Aqua",
}

a.spells["Leg Sweep as Interrupt"] = {
	ID = 119381--[[Leg Sweep]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	Melee = true,
	Check = function(z)
		return s.HasTalent(119381--[[Leg Sweep]]) and not s.Boss("target")
	end,
	FlashColor = "Aqua",
}

a.spells["leg_sweep"] = {
	ID = 119381--[[Leg Sweep]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return s.HasTalent(119381--[[Leg Sweep]]) and not s.Boss("target")
	end,
	Continue = true,
}

a.spells["Provoke"] = {
	ID = 115546--[[Provoke]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return s.Form(115069--[[Stance of the Sturdy Ox]]) and x.NoCC and x.ThreatPercent <= 99 and ( GetNumGroupMembers() > 1 or GetNumSubgroupMembers() > 0 ) and x.InCombat
	end,
	NoGCD = true,
	FlashColor = "Purple",
}

a.spells["Clash"] = {
	ID = 122057--[[Clash]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC and not s.MeleeDistance("target")
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["Roll"] = {
	ID = 109132--[[Roll]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return not s.MeleeDistance("target")
	end,
	NoGCD = true,
	FlashColor = "Pink",
}

a.spells["Dizzying Haze"] = {
	ID = 115180--[[Dizzying Haze]],
	Debuff = 115180--[[Dizzying Haze]],
	EnemyTargetNeeded = true,
	NoRangeCheck = true,
	FlashColor = "Blue",
}